@@ -45,7 +45,7 @@ glmregNB <- function(formula, data, weights, offset=NULL, nlambda=100, lambda=NU
     etastart <- model.extract(mf, "etastart")
 ### thoughts: use glm.nb to estimate intercept-only model which can take care of theta estimate 
     if(is.null(lambda)){
-        lmax <- findlam(x=X[,-1], y=Y, weights=weights, family="negbin", theta=NULL, mu=NULL, w=NULL, z=NULL, alpha=alpha, penalty.factor=penalty.factor, standardize=standardize)
+        lmax <- findlam(x=X[,-1], y=Y, weights=weights, family="negbin", theta=NULL, w=NULL, z=NULL, alpha=alpha, penalty.factor=penalty.factor, standardize=standardize)
         lpath <- seq(log(lmax), log(lambda.min.ratio * lmax), length.out=nlambda)
         lambda <- exp(lpath)
     }
@@ -169,7 +169,7 @@ glmregNB <- function(formula, data, weights, offset=NULL, nlambda=100, lambda=NU
     fit$contrasts <- attr(X, "contrasts")
     fit$xlevels <- .getXlevels(Terms, mf)
     fit$method <- method
-    fit$offset <- offset
+    fit$offset <- fit$offset
     if(is.null(colnames(X[,-1]))) varnames <- paste("V", 1:ncol(X[,-1]), sep="")
     else varnames <- colnames(X[,-1])
     dimnames(beta) <- list(varnames, round(lambda, digits=4))
